@@ -6,13 +6,11 @@ from .configuration.userconfiguration import UserConfiguration
 from .configuration.endpoint import Endpoint
 from .configuration.autodiscover import Autodiscover
 from .configuration.credentials import Credentials
-from .service.serviceendpoint import ServiceEndpoint
 from .service.resolvenames import ResolveNames
 from .service.deleteitem import DeleteItem
 from .service.getinboxrules import GetInboxRules
 from .service.findhiddeninboxrules import FindHiddenInboxRules
 from .service.getsearchablemailboxes import GetSearchableMailboxes
 from .service.searchmailboxes import SearchMailboxes
-from .service.searchquery import SearchQuery
 from .utils.exchangeversion import ExchangeVersion
 from .utils.exceptions import CredentialsError, IncorrectParameters, SoapConnectionError, SoapConnectionRefused, ExchangeVersionError, ObjectType, SearchScopeError, SoapAccessDeniedError, SoapResponseHasError, SoapResponseIsNoneError, DeleteTypeError, UserConfigurationError
\ No newline at end of file
